@@ -46,9 +46,8 @@ class SentryClient(object):
         for filter_ in get_filters():
             kwargs = filter_(None).process(kwargs) or kwargs
         
-        # Make sure all additional data is coerced
-        if 'data' in kwargs:
-            kwargs['data'] = transform(kwargs['data'])
+        # Make sure all data is coerced
+        kwargs = transform(kwargs)
 
         return self.send(**kwargs)
 
@@ -61,11 +60,14 @@ class SentryClient(object):
                 }
                 try:
                     urlread(url, post=data, timeout=conf.REMOTE_TIMEOUT)
-                except urllib2.URLError, e:
-                    logger.error('Unable to reach Sentry log server: %s' % (e,), exc_info=sys.exc_info(), extra={'remote_url': url})
-                    logger.log(kwargs.pop('level', None) or logging.ERROR, kwargs.pop('message', None))
                 except urllib2.HTTPError, e:
-                    logger.error('Unable to reach Sentry log server: %s' % (e,), exc_info=sys.exc_info(), extra={'body': e.read(), 'remote_url': url})
+                    body = e.read()
+                    logger.error('Unable to reach Sentry log server: %s (url: %%s, body: %%s)' % (e,), url, body,
+                                 exc_info=sys.exc_info(), extra={'data':{'body': body, 'remote_url': url}})
+                    logger.log(kwargs.pop('level', None) or logging.ERROR, kwargs.pop('message', None))
+                except urllib2.URLError, e:
+                    logger.error('Unable to reach Sentry log server: %s (url: %%s)' % (e,), url,
+                                 exc_info=sys.exc_info(), extra={'data':{'remote_url': url}})
                     logger.log(kwargs.pop('level', None) or logging.ERROR, kwargs.pop('message', None))
         else:
             from sentry.models import GroupedMessage
